@@ -7,10 +7,10 @@ import dataclasses
 import logging
 import os
 from pathlib import Path
-from typing import List, Dict
+from typing import Dict, List
 
 from .. import configuration as configuration_module, error as error_module
-from . import commands, query, server_connection, remote_logging
+from . import commands, query, remote_logging, server_connection
 
 
 LOG: logging.Logger = logging.getLogger(__name__)
